% This script converts the data contained in the netcdf file associated 
% to Laruelle et al. 2017 into a 216 by 720 by 1440 matrix.
% The script also converts the scaled data into uatm using a scaling factor

ncid = netcdf.open('Coastal_SOM_FFN_2017.nc','NOWRITE');

Time=netcdf.getVar(ncid,0);
Lat=netcdf.getVar(ncid,1);
Lon=netcdf.getVar(ncid,2);
Scaling_factor=netcdf.getVar(ncid,3);  
Var=netcdf.getVar(ncid,4);  
netcdf.close(ncid)

Var=single(Var);    % converts data from integer into single precision real
Var=Var/Scaling_factor; % converts data back into uatm using scaling factor
N=Var==-999;	% identifies cells covered in ice and replaces data with NaN
Var(N)=NaN;

pCO2=NaN*ones(216,720,1440);
l=length(Lon);
t=length(Time);
lon=[-179.875:.25:179.875];
lat=[-89.875:.25:89.875];

for i=1:1:t         % creates 216 by 720 by 1440 matrix
    for j=1:1:l
        pCO2(i,Lat(j)*4+360.5,Lon(j)*4+720.5)=Var(j,i);
    end
end

save Coastal_pCO2.mat pCO2 -v7.3

pcolor(lon,lat,squeeze(nanmean(pCO2)));shading flat
title('mean pCO2 over 1998-2015 in uatm')
xlabel('Latitude')
ylabel('Longitude')
colorbar;caxis([230 450]);

